@@ -1,6 +1,6 @@
 # /*##########################################################################
 #
-# Copyright (c) 2016-2022 European Synchrotron Radiation Facility
+# Copyright (c) 2016-2024 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,6 +21,7 @@
 # THE SOFTWARE.
 #
 # ###########################################################################*/
+from __future__ import annotations
 """Text rasterisation feature leveraging Qt font and text layout support."""
 
 __authors__ = ["T. Vincent"]
@@ -33,75 +34,42 @@ import numpy
 
 from .. import qt
 from ..utils.image import convertQImageToArray
+from ..utils.matplotlib import rasterMathText
 
-try:
-    from ..utils.matplotlib import rasterMathText
-except ImportError:
-    rasterMathText = None
 
 _logger = logging.getLogger(__name__)
 
 
-def getDefaultFontFamily():
+def getDefaultFontFamily() -> str:
     """Returns the default font family of the application"""
     return qt.QApplication.instance().font().family()
 
 
-# Font weights
-ULTRA_LIGHT = 0
-"""Lightest characters: Minimum font weight"""
-
-LIGHT = 25
-"""Light characters"""
-
-NORMAL = 50
-"""Normal characters"""
-
-SEMI_BOLD = 63
-"""Between normal and bold characters"""
-
-BOLD = 74
-"""Thicker characters"""
-
-BLACK = 87
-"""Really thick characters"""
-
-ULTRA_BLACK = 99
-"""Thickest characters: Maximum font weight"""
-
-
-def rasterTextQt(text, font, size=-1, weight=-1, italic=False, devicePixelRatio=1.0):
+def rasterTextQt(
+    text: str,
+    font: qt.QFont,
+    dotsPerInch: float = 96.0,
+) -> tuple[numpy.ndarray, float]:
     """Raster text using Qt.
 
     It supports multiple lines.
 
-    :param str text: The text to raster
-    :param font: Font name or QFont to use
-    :type font: str or :class:`QFont`
-    :param int size:
-        Font size in points
-        Used only if font is given as name.
-    :param int weight:
-        Font weight in [0, 99], see QFont.Weight.
-        Used only if font is given as name.
-    :param bool italic:
-        True for italic font (default: False).
-        Used only if font is given as name.
-    :param float devicePixelRatio:
-        The current ratio between device and device-independent pixel
-        (default: 1.0)
+    :param text: The text to raster
+    :param font: Font to use
+    :param dotsPerInch: The DPI resolution of the created image
     :return: Corresponding image in gray scale and baseline offset from top
-    :rtype: (HxW numpy.ndarray of uint8, int)
     """
     if not text:
         _logger.info("Trying to raster empty text, replaced by white space")
         text = " "  # Replace empty text by white space to produce an image
 
-    if not isinstance(font, qt.QFont):
-        font = qt.QFont(font, size, weight, italic)
+    dotsPerMeter = int(dotsPerInch * 100 / 2.54)
 
     # get text size
-    image = qt.QImage(1, 1, qt.QImage.Format_RGB888)
+    image = qt.QImage(1, 1, qt.QImage.Format_Grayscale8)
+    image.setDotsPerMeterX(dotsPerMeter)
+    image.setDotsPerMeterY(dotsPerMeter)
+
     painter = qt.QPainter()
     painter.begin(image)
     painter.setPen(qt.Qt.white)
@@ -112,6 +80,7 @@ def rasterTextQt(text, font, size=-1, weight=-1, italic=False, devicePixelRatio=
     painter.end()
 
     metrics = qt.QFontMetrics(font)
+    offset = metrics.ascent() / 72.0 * dotsPerInch
 
     # This does not provide the correct text bbox on macOS
     # size = metrics.size(qt.Qt.TextExpandTabs, text)
@@ -120,16 +89,17 @@ def rasterTextQt(text, font, size=-1, weight=-1, italic=False, devicePixelRatio=
     #     qt.Qt.TextExpandTabs,
     #     text)
 
-    # Add extra border and handle devicePixelRatio
-    width = bounds.width() * devicePixelRatio + 2
+    # Add extra border
+    width = bounds.width() + 2
     # align line size to 32 bits to ease conversion to numpy array
     width = 4 * ((width + 3) // 4)
     image = qt.QImage(
-        int(width), int(bounds.height() * devicePixelRatio + 2), qt.QImage.Format_RGB888
+        int(width),
+        int(bounds.height() + 2),
+        qt.QImage.Format_Grayscale8,
     )
-    image.setDevicePixelRatio(devicePixelRatio)
-
-    # TODO if Qt5 use Format_Grayscale8 instead
+    image.setDotsPerMeterX(dotsPerMeter)
+    image.setDotsPerMeterY(dotsPerMeter)
     image.fill(0)
 
     # Raster text
@@ -142,48 +112,38 @@ def rasterTextQt(text, font, size=-1, weight=-1, italic=False, devicePixelRatio=
 
     array = convertQImageToArray(image)
 
-    # RGB to R
-    array = numpy.ascontiguousarray(array[:, :, 0])
-
     # Remove leading and trailing empty columns/rows but one on each side
     filled_rows = numpy.nonzero(numpy.sum(array, axis=1))[0]
     filled_columns = numpy.nonzero(numpy.sum(array, axis=0))[0]
+
     if len(filled_rows) == 0 or len(filled_columns) == 0:
-        return array, metrics.ascent()
-
-    min_row = max(0, filled_rows[0] - 1)
-    array = array[
-        min_row : filled_rows[-1] + 2,
-        max(0, filled_columns[0] - 1) : filled_columns[-1] + 2,
-    ]
-
-    return array, metrics.ascent() - min_row
+        return array, offset
+    return (
+        numpy.ascontiguousarray(
+            array[
+                0 : filled_rows[-1] + 2,
+                max(0, filled_columns[0] - 1) : filled_columns[-1] + 2,
+            ]
+        ),
+        offset,
+    )
 
 
-def rasterText(text, font, size=-1, weight=-1, italic=False, devicePixelRatio=1.0):
+def rasterText(
+    text: str,
+    font: qt.QFont,
+    dotsPerInch: float = 96.0,
+) -> tuple[numpy.ndarray, float]:
     """Raster text using Qt or matplotlib if there may be math syntax.
 
     It supports multiple lines.
 
-    :param str text: The text to raster
+    :param text: The text to raster
     :param font: Font name or QFont to use
-    :type font: str or :class:`QFont`
-    :param int size:
-        Font size in points
-        Used only if font is given as name.
-    :param int weight:
-        Font weight in [0, 99], see QFont.Weight.
-        Used only if font is given as name.
-    :param bool italic:
-        True for italic font (default: False).
-        Used only if font is given as name.
-    :param float devicePixelRatio:
-        The current ratio between device and device-independent pixel
-        (default: 1.0)
+    :param dotsPerInch: Created image resolution
     :return: Corresponding image in gray scale and baseline offset from top
-    :rtype: (HxW numpy.ndarray of uint8, int)
     """
-    if rasterMathText is not None and text.count("$") >= 2:
-        return rasterMathText(text, font, size, weight, italic, devicePixelRatio)
-    else:
-        return rasterTextQt(text, font, size, weight, italic, devicePixelRatio)
+
+    if text.count("$") >= 2:
+        return rasterMathText(text, font, dotsPerInch)
+    return rasterTextQt(text, font, dotsPerInch)
